@@ -24,10 +24,12 @@
 #include <config.h>
 #endif
 
+#define _GNU_SOURCE
 #include <stdio.h>
 #include <unistd.h>
 #include <stdlib.h>
 #include <assert.h>
+#include <signal.h>
 
 #include <ell/ell.h>
 
@@ -38,8 +40,7 @@ static void do_debug(const char *str, void *user_data)
 	l_info("%s%s", prefix, str);
 }
 
-static void signal_handler(struct l_signal *signal, uint32_t signo,
-							void *user_data)
+static void signal_handler(uint32_t signo, void *user_data)
 {
 	switch (signo) {
 	case SIGINT:
@@ -131,19 +132,12 @@ int main(int argc, char *argv[])
 {
 	struct l_dbus_client *client;
 	struct l_dbus *dbus;
-	struct l_signal *signal;
-	sigset_t mask;
 	uint32_t iwd_watch_id;
 
 
 	if (!l_main_init())
 		return -1;
 
-	sigemptyset(&mask);
-	sigaddset(&mask, SIGINT);
-	sigaddset(&mask, SIGTERM);
-	signal = l_signal_create(&mask, signal_handler, NULL, NULL);
-
 	l_log_set_stderr();
 
 	dbus = l_dbus_new_default(L_DBUS_SYSTEM_BUS);
@@ -171,14 +165,13 @@ int main(int argc, char *argv[])
 	l_dbus_client_set_ready_handler(client, bluez_client_ready, NULL, NULL);
 
 
-	l_main_run();
+	l_main_run_with_signal(signal_handler, NULL);
 
 	l_dbus_remove_watch(dbus, iwd_watch_id);
 
 	l_dbus_client_destroy(client);
 
 	l_dbus_destroy(dbus);
-	l_signal_remove(signal);
 
 	l_main_exit();
 
